classdef Point2d < handle
  % Point2d
  %   2D point for indexing into array
  %
  % Methods:
  %   row - Get the row value
  %   col - Get the column value
  %

  properties(Access=protected)
    mPtr = uint64(0);
  end

  methods(Access=public)
    function obj = Point2d(varargin)
      % Point2d
      %   Construct new point_2d class
      %

      if nargin == 1 && isa(varargin{1}, 'uint64')
        obj.mPtr = varargin{1};
      else
        error("Can't construct empty object");
      end
    end


    function delete(obj)
      if obj.mPtr ~= 0
        tof.mex('tof_point_2d_delete', obj.mPtr);
        obj.mPtr = 0;
      end
    end

    function ptr = get_object_ptr(obj)
      ptr = obj.mPtr;
    end

    function ret_val = row(obj)
      % row
      %   Get the row value
      %
      % Output:
      %   ret_val - numeric - Row value
      %

      ret_val = tof.mex('tof_point_2d_row', obj.mPtr);
      ret_val = double(ret_val);
    end

    function ret_val = col(obj)
      % col
      %   Get the column value
      %
      % Output:
      %   ret_val - numeric - Column value
      %

      ret_val = tof.mex('tof_point_2d_col', obj.mPtr);
      ret_val = double(ret_val);
    end

  end
end
